@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,7 +19,7 @@ CSVImportExportPlugin::~CSVImportExportPlugin() = default;
 
 PimCommon::AbstractGenericPluginInterface *CSVImportExportPlugin::createInterface(QObject *parent)
 {
-    auto *interface = new CSVImportExportPluginInterface(parent);
+    auto interface = new CSVImportExportPluginInterface(parent);
     return interface;
 }
 
