@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MARKDOWNPREVIEWWIDGET_H
-#define MARKDOWNPREVIEWWIDGET_H
+#pragma once
 
 #include "markdownlib_private_export.h"
 #include <QWidget>
@@ -27,8 +26,7 @@ private:
     void slotLinkHovered(const QString &url);
     void converterFailed(const QString &msg);
     QWebEngineView *mWebView = nullptr;
-    MarkdownConverter *mConverter = nullptr;
+    MarkdownConverter *const mConverter;
     QLabel *mHoverUrlLabel = nullptr;
 };
 
-#endif // MARKDOWNPREVIEWWIDGET_H
