@@ -4,14 +4,13 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef EXTERNALCOMPOSERCONFIGUREWIDGET_H
-#define EXTERNALCOMPOSERCONFIGUREWIDGET_H
+#pragma once
 
-#include <MessageComposer/PluginEditorInitConfigureWidget>
-#include <QWidget>
+#include <MessageComposer/PluginEditorConfigureBaseWidget>
+class QWidget;
 class QCheckBox;
 class KUrlRequester;
-class ExternalComposerConfigureWidget : public MessageComposer::PluginEditorInitConfigureWidget
+class ExternalComposerConfigureWidget : public MessageComposer::PluginEditorConfigureBaseWidget
 {
     Q_OBJECT
 public:
@@ -23,8 +22,7 @@ public:
     void resetSettings() override;
 
 private:
-    QCheckBox *mExternalEditorCheck = nullptr;
-    KUrlRequester *mEditorRequester = nullptr;
+    QCheckBox *const mExternalEditorCheck;
+    KUrlRequester *const mEditorRequester;
 };
 
-#endif // EXTERNALCOMPOSERCONFIGUREWIDGET_H
