@@ -5,16 +5,16 @@
 */
 
 #include "gnupgwksurlhandler.h"
-#include "gnupgwksmessagepart.h"
 #include "gnupgwks_debug.h"
+#include "gnupgwksmessagepart.h"
 
+#include <QProcess>
 #include <QString>
 #include <QUrlQuery>
-#include <QProcess>
 
+#include <MessageViewer/Viewer>
 #include <MimeTreeParser/BodyPart>
 #include <MimeTreeParser/NodeHelper>
-#include <MessageViewer/Viewer>
 
 #include <QGpgME/Protocol>
 #include <QGpgME/WKSPublishJob>
@@ -23,8 +23,8 @@
 #include <MailTransport/TransportManager>
 #include <MailTransportAkonadi/MessageQueueJob>
 
-#include <KIdentityManagement/IdentityManager>
 #include <KIdentityManagement/Identity>
+#include <KIdentityManagement/IdentityManager>
 
 #include <KMime/Util>
 
@@ -46,7 +46,7 @@ QString ApplicationGnuPGWKSUrlHandler::name() const
 
 bool ApplicationGnuPGWKSUrlHandler::handleClick(MessageViewer::Viewer *viewerInstance, BodyPart *part, const QString &path) const
 {
-    Q_UNUSED(viewerInstance);
+    Q_UNUSED(viewerInstance)
 
     if (!path.startsWith(QLatin1String("gnupgwks?"))) {
         return false;
@@ -54,8 +54,7 @@ bool ApplicationGnuPGWKSUrlHandler::handleClick(MessageViewer::Viewer *viewerIns
 
     const QUrlQuery q(path.mid(sizeof("gnupgwks?") - 1));
     if (q.queryItemValue(QStringLiteral("action")) == QLatin1String("show")) {
-        QProcess::startDetached(QStringLiteral("kleopatra"),
-                                { QStringLiteral("--query"), q.queryItemValue(QStringLiteral("fpr")) });
+        QProcess::startDetached(QStringLiteral("kleopatra"), {QStringLiteral("--query"), q.queryItemValue(QStringLiteral("fpr"))});
         return true;
     } else if (q.queryItemValue(QStringLiteral("action")) == QLatin1String("confirm")) {
         GnuPGWKSMessagePart mp(part);
@@ -70,7 +69,7 @@ bool ApplicationGnuPGWKSUrlHandler::handleClick(MessageViewer::Viewer *viewerIns
 
 QString ApplicationGnuPGWKSUrlHandler::statusBarMessage(BodyPart *part, const QString &path) const
 {
-    Q_UNUSED(part);
+    Q_UNUSED(part)
 
     if (!path.startsWith(QLatin1String("gnupgwks?"))) {
         return QString();
@@ -91,15 +90,15 @@ QByteArray ApplicationGnuPGWKSUrlHandler::createConfirmation(const KMime::Messag
     auto job = QGpgME::openpgp()->wksPublishJob();
     QEventLoop el;
     QByteArray result;
-    QObject::connect(job, &QGpgME::WKSPublishJob::result,
-                     [&el, &result](const GpgME::Error &, const QByteArray &returnedData,
-                                    const QByteArray &returnedError) {
-        if (returnedData.isEmpty()) {
-            qCWarning(GNUPGWKS_LOG) << "GPG:" << returnedError;
-        }
-        result = returnedData;
-        el.quit();
-    });
+    QObject::connect(job,
+                     &QGpgME::WKSPublishJob::result,
+                     [&el, &result](const GpgME::Error &, const QByteArray &returnedData, const QByteArray &returnedError) {
+                         if (returnedData.isEmpty()) {
+                             qCWarning(GNUPGWKS_LOG) << "GPG:" << returnedError;
+                         }
+                         result = returnedData;
+                         el.quit();
+                     });
     job->startReceive(msg->encodedContent());
     el.exec();
 
@@ -121,7 +120,7 @@ bool ApplicationGnuPGWKSUrlHandler::sendConfirmation(MessageViewer::Viewer *view
     const auto identity = KIdentityManagement::IdentityManager::self()->identityForAddress(mp.address());
     const bool nullIdentity = (identity == KIdentityManagement::Identity::null());
     if (!nullIdentity) {
-        auto *x_header = new KMime::Headers::Generic("X-KMail-Identity");
+        auto x_header = new KMime::Headers::Generic("X-KMail-Identity");
         x_header->from7BitString(QByteArray::number(identity.uoid()));
         msg->setHeader(x_header);
     }
@@ -152,7 +151,7 @@ bool ApplicationGnuPGWKSUrlHandler::sendConfirmation(MessageViewer::Viewer *view
     // Move to outbox
     auto transport = transportMgr->transportById(transportId);
     auto job = new MailTransport::MessageQueueJob;
-    job->addressAttribute().setTo({ msg->to(false)->asUnicodeString() });
+    job->addressAttribute().setTo({msg->to(false)->asUnicodeString()});
     job->transportAttribute().setTransportId(transport->id());
     job->addressAttribute().setFrom(msg->from(false)->asUnicodeString());
     job->sentBehaviourAttribute().setSentBehaviour(MailTransport::SentBehaviourAttribute::Delete);
